@@ -6,6 +6,8 @@ Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 
 from __future__ import print_function
 import sys
+import os
+import warnings
 from Pyro4 import errors, naming
 
 if sys.version_info < (3, 0):
@@ -116,9 +118,16 @@ def main(args=None):
     parser.add_option("-p", "--port", dest="port", type="int",
                       help="port of the NS (or bc-port if host isn't specified)")
     parser.add_option("-u", "--unixsocket", help="Unix domain socket name of the NS")
-    parser.add_option("-k", "--key", help="the HMAC key to use")
+    parser.add_option("-k", "--key", help="the HMAC key to use (deprecated)")
     parser.add_option("-v", "--verbose", action="store_true", dest="verbose", help="verbose output")
     options, args = parser.parse_args(args)
+    if options.key:
+        warnings.warn("using -k to supply HMAC key on the command line is a security problem "
+                      "and is deprecated since Pyro 4.72. See the documentation for an alternative.")
+    if "PYRO_HMAC_KEY" in os.environ:
+        if options.key:
+            raise SystemExit("error: don't use -k and PYRO_HMAC_KEY at the same time")
+        options.key = os.environ["PYRO_HMAC_KEY"]
     if not args or args[0] not in ("register", "remove", "removematching", "list", "listmatching", "lookup",
                                    "listmeta_all", "listmeta_any", "setmeta", "ping"):
         parser.error("invalid or missing command")
